@@ -43,6 +43,9 @@ def fetch_data(raw_data_id):
 
 
 def display_data(raw_data_string, raw_data_id, model_folder):
+    logging.info("raw_data_id: %i", raw_data_id)
+    logging.info("raw data:\n%s", raw_data_string)
+
     PROJECT_ROOT = utils.get_project_root()
 
     # Get model description
